# InviteUserRequest

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**email** | **str** | Max length 100 characters | 
**first_name** | **str** | Max length 50 characters | 
**last_name** | **str** | Max length 50 characters | 
**role** | **AllOfInviteUserRequestRole** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

